@@ -1,10 +1,10 @@
 use anyhow::Result;
 use async_std::task;
-use futures::prelude::*;
-use futures::stream::StreamExt;
+use futures_lite::prelude::*;
+use futures_lite::stream::StreamExt;
 use log::*;
-use piper::pipe;
 use pretty_bytes::converter::convert as pretty_bytes;
+use sluice::pipe::pipe;
 use std::env;
 use std::time::Instant;
 
@@ -33,8 +33,8 @@ impl Config {
     pub fn from_env() -> Self {
         Config {
             connections: parse_env_u64("CONNECTIONS", 10),
-            blocksize: parse_env_u64("BLOCKSIZE", 1000),
-            length: parse_env_u64("LENGTH", 10000),
+            blocksize: parse_env_u64("BLOCKSIZE", 100),
+            length: parse_env_u64("LENGTH", 1000),
             no_encrypt: env::var("NO_ENCRYPT").is_ok(),
         }
     }
@@ -42,19 +42,22 @@ impl Config {
 
 async fn run_echo_pipes(config: Config) -> Result<()> {
     let start = std::time::Instant::now();
-    let mut futs = vec![];
+    let mut tasks = vec![];
     for i in 0..config.connections {
-        futs.push(run_echo(config.clone(), i));
+        tasks.push(task::spawn(run_echo(config.clone(), i)));
     }
-    futures::future::join_all(futs).await;
+    for task in tasks {
+        task.await?;
+    }
+    // futures::future::join_all(futs).await;
     print_stats("total", start, config.total_bytes() as f64);
     Ok(())
 }
 
 async fn run_echo(config: Config, i: u64) -> Result<()> {
-    let cap: usize = config.blocksize as usize * 10;
-    let (ar, bw) = pipe(cap);
-    let (br, aw) = pipe(cap);
+    // let cap: usize = config.blocksize as usize * 10;
+    let (ar, bw) = pipe();
+    let (br, aw) = pipe();
 
     let mut a = ProtocolBuilder::new(true);
     let mut b = ProtocolBuilder::new(false);
@@ -75,16 +78,15 @@ async fn run_echo(config: Config, i: u64) -> Result<()> {
 
 // The onconnection handler is called for each incoming connection (if server)
 // or once when connected (if client).
-async fn onconnection<R, W>(config: Config, i: u64, mut protocol: Protocol<R, W>) -> Result<u64>
+async fn onconnection<IO>(config: Config, i: u64, mut protocol: Protocol<IO>) -> Result<u64>
 where
-    R: AsyncRead + Send + Unpin + 'static,
-    W: AsyncWrite + Send + Unpin + 'static,
+    IO: AsyncRead + AsyncWrite + Send + Unpin + 'static,
 {
-    let key = vec![0u8; 24];
+    let key = [0u8; 32];
     let is_initiator = protocol.is_initiator();
     // let mut len: u64 = 0;
-    loop {
-        match protocol.loop_next().await {
+    while let Some(event) = protocol.next().await {
+        match event {
             Ok(event) => {
                 debug!("[init {}] EVENT {:?}", is_initiator, event);
                 match event {
@@ -105,6 +107,7 @@ where
                     Event::Close(_) => {
                         return Ok(0);
                     }
+                    _ => {}
                 }
             }
             Err(err) => {
@@ -113,6 +116,7 @@ where
             }
         }
     }
+    Ok(0)
 }
 
 async fn on_channel_resp(_config: Config, _i: u64, mut channel: Channel) -> Result<u64> {
